..


.. Keep the current version number on line number 5
0.0.5
=====

2020-03-27

* Use 'subprocess.check_call'
* Add 'CONTRIBUTING.rst'
* Fix project dependency name 'importlib-metadata'
* Fix linting


0.0.4
=====

2019-10-10

* Allow *pip* to build *wheels* in the temporary virtual environment


0.0.3
=====

2019-10-03

* Improve packaging


0.0.2
=====

2019-06-11

* Code refactored for easier usage as a library


0.0.1
=====

2019-05-07

Initial version


.. EOF
